// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVELOP_VERSION_H
#define KDEVELOP_VERSION_H

#define KDEVELOP_VERSION_STRING "5.6.2"
#define KDEVELOP_VERSION_MAJOR 5
#define KDEVELOP_VERSION_MINOR 6
#define KDEVELOP_VERSION_PATCH 2
#define KDEVELOP_VERSION ((5<<16)|(6<<8)|(2))

#endif
